@@ -1,6 +1,7 @@
 from django.contrib.auth import SESSION_KEY
 from django.conf import settings
-from rest_framework.response import Response
+from django.http import HttpResponse
+from django.middleware.csrf import get_token
 from errors import WsResponseError, WsInvocationError
 import httplib, json, proxy_server
 
@@ -63,7 +64,7 @@ def invoke_backend_service(method, function_path, json_data=dict(), request=None
     else:
         raise WsInvocationError('No backend host and/or port specified')
 
-def invoke_backend_service_as_proxy(method, function_path, json_data=dict(), request=None, response_token=True, secure=False):
+def invoke_backend_service_as_proxy(request, method, function_path, json_data=dict(), response_token=True, secure=False):
     if hasattr(settings, 'BACKEND_HOST'):
         if secure:
             if hasattr(settings, 'BACKEND_PORT'):
@@ -77,11 +78,9 @@ def invoke_backend_service_as_proxy(method, function_path, json_data=dict(), req
                 raise WsInvocationError('No port supplied')
 
         headers = proxy_server.RESTFUL_HEADER
-
-        if request is not None:
-            headers[proxy_server.USER_TOKEN] = request.META.get(proxy_server.HTTP_USER_TOKEN)
-            headers[proxy_server.CLIENT_IP] = request.META.get(proxy_server.HTTP_FROM)
-            headers[proxy_server.API_KEY] = request.META.get(proxy_server.HTTP_API_KEY)
+        headers[proxy_server.USER_TOKEN] = request.META.get(proxy_server.HTTP_USER_TOKEN)
+        headers[proxy_server.CLIENT_IP] = request.META.get(proxy_server.HTTP_FROM)
+        headers[proxy_server.API_KEY] = request.META.get(proxy_server.HTTP_API_KEY)
 
         try:
             conn.request(method, function_path, json.dumps(json_data), headers)
@@ -92,9 +91,9 @@ def invoke_backend_service_as_proxy(method, function_path, json_data=dict(), req
         response_data = response.read()
         conn.close()
 
-        response_json = json.loads(response_data)
-
         if response.status is 200 or response.status is 204:
+            response_json = json.loads(response_data)
+
             if response.status is 200:
                 if response_token and proxy_server.USER_TOKEN not in response_json:
                     raise WsResponseError('Server expected user token in response')
@@ -103,18 +102,18 @@ def invoke_backend_service_as_proxy(method, function_path, json_data=dict(), req
                 if response_token:
                     raise WsResponseError('Backend server didn\'t respond with a token')
 
-            headers = dict()
-            for header, value in response.getheaders():
-                headers[header] = value
+            request.META["CSRF_COOKIE_USED"] = True
 
-            if response.status is 204:
-                resp = Response(status=response.status, headers=headers, content_type='application/json')
-            else:
-                resp = Response(data=response_data, status=response.status, headers=headers, content_type='application/json')
+            resp = HttpResponse(response_data, status=response.status, content_type='application/json', reason=response.reason)
+            for header, value in response.getheaders():
+                resp[header] = value
+
+            if not resp.has_header(proxy_server.CSRF_TOKEN):
+                resp[proxy_server.CSRF_TOKEN] = get_token(request)
 
             return resp
-        else:
-            if proxy_server.ERROR in response_json:
+        elif response.status:
+            if proxy_server.ERROR in response_data:
                 raise WsResponseError(response_json[proxy_server.ERROR][proxy_server.MESSAGE])
             else:
                 raise WsResponseError('Unknown error in backend server')
