@@ -9,16 +9,16 @@ from django.test.client import Client
 class ProxyServicesTest(TestCase):
     def test_invoke_backend_service(self):
         c = Client()
-        response = c.post('/test/', **{'HTTP_API_KEY':'^ugfp@+cw!+se1b8kw%!23(sbrzk8f!uzrhqp$s)@67g9f1tdj', 'HTTP_X_FORWARDED_FOR':'127.0.0.1'})
-        print 'Invoke backend as proxy response 200:', response.content
+        response = c.post('/test/', **{'HTTP_API_KEY':'^ugfp@+cw!+se1b8kw%!23(sbrzk8f!uzrhqp$s)@67g9f1tdj', 'HTTP_X_FORWARDED_FOR':'127.0.0.1', 'HTTP_X_CSRFTOKEN':'v71AUma9qIKbO4KEmboJ9TOZuh3wejM6'})
+        print 'Invoke backend as proxy response 200:', response
 
         try:
-            c.get('/test_error/', **{'HTTP_API_KEY':'^ugfp@+cw!+se1b8kw%!23(sbrzk8f!uzrhqp$s)@67g9f1tdj', 'HTTP_X_FORWARDED_FOR':'127.0.0.1'})
+            c.get('/test_error/', **{'HTTP_API_KEY':'^ugfp@+cw!+se1b8kw%!23(sbrzk8f!uzrhqp$s)@67g9f1tdj', 'HTTP_X_FORWARDED_FOR':'127.0.0.1','HTTP_X_CSRFTOKEN':'v71AUma9qIKbO4KEmboJ9TOZuh3wejM6'})
         except Exception as e:
             print 'Invoke backend as proxy response 500:', str(e)
 
-        response = c.get('/test_token_validation/', **{'HTTP_API_KEY':'^ugfp@+cw!+se1b8kw%!23(sbrzk8f!uzrhqp$s)@67g9f1tdj', 'HTTP_X_FORWARDED_FOR':'127.0.0.1', 'HTTP_USER_TOKEN':'123token'})
-        print 'Invoke backend as proxy response token_validation:', response.content
+        response = c.get('/test_token_validation/', **{'HTTP_API_KEY':'^ugfp@+cw!+se1b8kw%!23(sbrzk8f!uzrhqp$s)@67g9f1tdj', 'HTTP_X_FORWARDED_FOR':'127.0.0.1', 'HTTP_USER_TOKEN':'123token','HTTP_X_CSRFTOKEN':'v71AUma9qIKbO4KEmboJ9TOZuh3wejM6'})
+        print 'Invoke backend as proxy response token_validation:', response
 
 class BackendServicesTest(TestCase):
     def test_invoke_backend_service(self):
