@@ -7,15 +7,15 @@ import json
 @expose_service(['POST'], public=True)
 def test(request):
     service_url = generate_service_url('/login')
-    return invoke_backend_service_as_proxy('POST', service_url, json_data={ 'email':'admin@test.com', 'password':'password' }, request=request)
+    return invoke_backend_service_as_proxy(request, 'POST', service_url, json_data={ 'email':'admin@test.com', 'password':'password' })
 
 
 @expose_service(['GET'], public=True)
 def test_error(request):
     service_url = generate_service_url('/login')
-    return invoke_backend_service_as_proxy('POST', service_url, json_data={ 'email':'admin@test.com' }, request=request)
+    return invoke_backend_service_as_proxy(request, 'POST', service_url, json_data={ 'email':'admin@test.com' })
 
 @expose_service(['GET'])
 def test_token_validation(request):
     service_url = generate_service_url('/login')
-    return invoke_backend_service_as_proxy('POST', service_url, json_data={ 'email':'admin@test.com', 'password':'password' }, request=request)
+    return invoke_backend_service_as_proxy(request, 'POST', service_url, json_data={ 'email':'admin@test.com', 'password':'password' })
